package com.citygis.common.boot.enums;

import jakarta.servlet.http.HttpServletResponse;
import lombok.Getter;

/**
 * 系统状态枚举
 */
@Getter
public enum SystemStatusCodeEnum {
    READY(0, HttpServletResponse.SC_OK, "ready", "准备就绪"),
    ACTIVE(1, HttpServletResponse.SC_OK, "active", "活动"),
    RUNNING(2, HttpServletResponse.SC_OK,  "running", "运行中"),
    STOP(3, HttpServletResponse.SC_OK, "stopped", "已停止"),
    WAITING(4, HttpServletResponse.SC_OK, "waiting", "等待"),
    PAUSE(5, HttpServletResponse.SC_OK, "pause", "暂停"),
    DELETED(6, HttpServletResponse.SC_OK, "deleted", "被删除"),
    EXITED(7, HttpServletResponse.SC_OK, "exited", "退出"),
    DISABLED(8, HttpServletResponse.SC_OK, "disabled", "禁用状态码"),
    SUCCESS(1000, HttpServletResponse.SC_OK, "success", "业务成功状态码"),
    FAIL(2000, HttpServletResponse.SC_BAD_REQUEST, "fail", "业务失败状态码"),
    FAIL_INIT(2001, HttpServletResponse.SC_BAD_REQUEST,"fail_init", "业务上初始化未完成"),
    FAIL_LIC(2002, HttpServletResponse.SC_FORBIDDEN,"fail_lic", "license校验失败"),
    FAIL_LIC_NOTFOUND(2004, HttpServletResponse.SC_BAD_REQUEST,"fail_lic_notFound", "license不存在"),
    FAIL_PARAMETER(2003, HttpServletResponse.SC_BAD_REQUEST,"fail_parameter", "参数异常"),
    ERROR(3000, HttpServletResponse.SC_INTERNAL_SERVER_ERROR,"error", "业务错误状态码"),
    WARNING(4000, HttpServletResponse.SC_OK,"warning", "警告状态码"),
    IGNORE(5000, HttpServletResponse.SC_OK,"ignore", "忽略状态码"),
    PERMISSION_TOKEN_EXPIRED(6000, HttpServletResponse.SC_FORBIDDEN,"error", "token已过期"),
    PERMISSION_TOKEN_INVALID(6001, HttpServletResponse.SC_FORBIDDEN,"error", "token无效"),
    PERMISSION_SIGNATURE_ERROR(6002, HttpServletResponse.SC_UNAUTHORIZED,"error", "签名失败"),
    PERMISSION_TOKEN_NOTFOUND(6003, HttpServletResponse.SC_UNAUTHORIZED,"error", "token未能找到，需要重新认证获取。");

    private final int value;
    private final int httpCode;
    private final String displayName;
    private final String desc;

    /**
     * 构造函数
     * @param value 业务状态码的值
     * @param httpCode 对应的http状态码值
     * @param displayName 显示名称
     * @param desc 描述
     */
    SystemStatusCodeEnum(int value, int httpCode, String displayName, String desc) {
        this.value = value;
        this.httpCode = httpCode;
        this.displayName = displayName;
        this.desc = desc;
    }
}
