package com.citygis.common.boot.exception;

import com.citygis.common.boot.enums.SystemStatusCodeEnum;
import jakarta.servlet.http.HttpServletResponse;
import lombok.Getter;
import lombok.Setter;

/**
 * 业务错误类
 */
@Getter
@Setter
public class BusinessException extends RuntimeException {

    private int httpCode = HttpServletResponse.SC_INTERNAL_SERVER_ERROR;
    /**
     * 业务异常编码
     */
    private int code = 3000;
    /**
     * 异常数据
     */
    private Object content;

    /**
     * 无参构造函数
     */
    public BusinessException() {
    }

    /**
     * @param message 错误内容
     */
    public BusinessException(String message) {
        super(message);
    }

    /**
     * @param code    业务异常编码
     * @param message 错误内容
     */
    public BusinessException(int code, String message) {
        super(message);
        this.code = code;
        this.httpCode = HttpServletResponse.SC_OK;
    }

    /**
     * @param status  异常状态枚举
     * @param message 错误内容
     */
    public BusinessException(SystemStatusCodeEnum status, String message) {
        this(status.getValue(), message);
    }

    /**
     * @param status   异常状态枚举
     * @param httpCode http响应编码（int）
     * @param message  错误内容
     */
    public BusinessException(SystemStatusCodeEnum status, int httpCode, String message) {
        this(status.getValue(), message);
        this.httpCode = httpCode;
    }

    /**
     * @param status  异常状态枚举
     * @param data    数据
     * @param message 错误内容
     */
    public BusinessException(SystemStatusCodeEnum status, Object data, String message) {
        this(status, message);
        this.content = data;
    }

    /**
     * @param status   异常状态枚举
     * @param httpCode http响应编码（int）
     * @param data     数据
     * @param message  错误内容
     */
    public BusinessException(SystemStatusCodeEnum status, int httpCode, Object data, String message) {
        this(status, httpCode, message);
        this.content = data;
    }
}
