package com.citygis.common.boot.util;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.citygis.common.boot.constant.constant;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;

/**
 * 时间工具类
 */
public final class DateUtil {
    private static final Logger LOG = LoggerFactory.getLogger(DateUtil.class);

    /**
     * 获取当前服务器毫秒时间
     *
     * @return 当前服务器毫秒时间
     */
    public static Long currentTimeMillis() {
        return System.currentTimeMillis();
    }

    /**
     * 获取当前年月日时分秒时间
     *
     * @return 当前年月日时分秒时间
     */
    public static String currentTime() {
        Date now = new Date();
        // 格式化
        SimpleDateFormat sim = new SimpleDateFormat(constant.DATE.SIMPLE_DATE_FORMAT);
        return sim.format(now);
    }

    /**
     * 字符串根据默认格式转换成时间格式
     *
     * @param str 时间戳字符串
     * @return 转换后时间戳
     */
    public static Date parseDate(String str) {
        try {
            return new SimpleDateFormat(constant.DATE.DEFAULT_FORMAT).parse(str);
        } catch (ParseException e) {
            LOG.error(e.getMessage(), e);
            return null;
        }
    }

    /**
     * 毫秒转日期
     *
     * @param millisecond 毫秒
     * @return 日期
     */
    public static Date parseMs(long millisecond) {
        return cn.hutool.core.date.DateUtil.date(millisecond);
    }

    /**
     * 根据输入时间和时间差计算目标时间
     *
     * @param date 输入时间
     * @param day  想要获取的日期与传入日期的差值 比如想要获取传入日期前x天的日期 day=-x即可
     * @return 目标时间
     */
    public static Date getSomeDay(Date date, int day) {
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(date);
        calendar.add(Calendar.DATE, day);
        return calendar.getTime();
    }
}