package com.citygis.common.boot.util;

import java.net.InetAddress;
import java.net.UnknownHostException;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.citygis.common.boot.constant.constant;
import com.citygis.common.boot.define.HttpHeaderNames;
import com.citygis.common.boot.enums.UserAgentTypeEnum;

import jakarta.servlet.http.HttpServletRequest;

/**
 * net帮助类
 */
public final class NetAssist {
    private static final Logger LOG = LoggerFactory.getLogger(NetAssist.class);

    /**
     * 获取本地ip
     *
     * @return 本地ip
     */
    public static String getLocalHost() {
        try {
            InetAddress address = InetAddress.getLocalHost();
            return address.getHostAddress();
        } catch (UnknownHostException e) {
            LOG.error(e.getMessage(), e);
        }
        return StringUtil.EMPTY;
    }

    /**
     * 获取终端类型
     *
     * @param userAgent 请求的客户端类型名称
     * @return 终端类型
     */
    public static UserAgentTypeEnum getUserAgentType(String userAgent) {
        if (StringUtil.isNullOrEmpty(userAgent)) {
            return UserAgentTypeEnum.UNKNOWN;
        }
        userAgent = userAgent.toLowerCase();
        for (String mobileAgent : constant.NET_ASSIST.MOBILE_AGENTS) {
            if (userAgent.toLowerCase().contains(mobileAgent)) {
                return UserAgentTypeEnum.MOBILE;
            }
        }
        if (userAgent.indexOf(constant.NET_ASSIST.WECHAT_BUILT_IN_BROWSER) > 0) {
            return UserAgentTypeEnum.WECHAT;
        }
        return UserAgentTypeEnum.BROWSER;
    }

    /**
     * 获取请求主机IP地址,如果通过代理进来，则透过防火墙获取真实IP地址;
     *
     * @param request 请求
     * @return 主机IP地址
     */
    public static String getClientIpAddress(HttpServletRequest request) {
        String ip = request.getHeader(constant.NET_ASSIST.IP_HEADER);
        if (ip == null || ip.length() == 0 || constant.NET_ASSIST.UNKNOWN.equalsIgnoreCase(ip)) {
            if (ip == null || ip.length() == 0 || constant.NET_ASSIST.UNKNOWN.equalsIgnoreCase(ip)) {
                ip = request.getHeader(constant.NET_ASSIST.PROXY_CLIENT_IP_HEADER);
            }
            if (ip == null || ip.length() == 0 || constant.NET_ASSIST.UNKNOWN.equalsIgnoreCase(ip)) {
                ip = request.getHeader(constant.NET_ASSIST.WL_PROXY_CLIENT_IP_HEADER);
            }
            if (ip == null || ip.length() == 0 || constant.NET_ASSIST.UNKNOWN.equalsIgnoreCase(ip)) {
                ip = request.getHeader(constant.NET_ASSIST.HTTP_CLIENT_IP_HEADER);
            }
            if (ip == null || ip.length() == 0 || constant.NET_ASSIST.UNKNOWN.equalsIgnoreCase(ip)) {
                ip = request.getHeader(constant.NET_ASSIST.HTTP_X_FORWARDED_FOR_HEADER);
            }
            if (ip == null || ip.length() == 0 || constant.NET_ASSIST.UNKNOWN.equalsIgnoreCase(ip)) {
                ip = request.getRemoteAddr();
            }
        } else if (ip.length() > 15) {
            String[] ips = ip.split(constant.STRING.COMMA);
            for (String s : ips) {
                if (!(constant.NET_ASSIST.UNKNOWN.equalsIgnoreCase(s))) {
                    ip = s;
                    break;
                }
            }
        }
        return ip;
    }

    public static String getAgent(HttpServletRequest request) {
        return request.getHeader(HttpHeaderNames.UserAgent);
    }
}