package com.citygis.common.boot.util;

import java.io.File;
import java.nio.file.Paths;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.citygis.common.boot.constant.constant;

/**
 * 路径工具类
 */
public final class PathUtil {
    private final static Logger LOG = LoggerFactory.getLogger(PathUtil.class);

    /**
     * 组合路径
     *
     * @param firstPath  首路径
     * @param otherPaths 后续路径
     * @return 组合路径
     */
    public static String combine(String firstPath, String... otherPaths) {

        if (null == otherPaths || 0 == otherPaths.length) {
            return firstPath;
        }
        return Paths.get(firstPath, otherPaths).toString();
    }

    /**
     * 获取文件所在的目录的名字
     *
     * @param path 路径
     * @return 目录名字
     */
    public static String getDirectoryName(String path) {
        File file = new File(path);
        if (file.exists()) {
            if (file.isDirectory()) {
                return file.getName();
            }
            // 如果是文件，则返回所在目录文件夹的名称
            return file.getParentFile().getName();
        }
        return StringUtil.EMPTY;
    }

    /**
     * 获取文件所在的目录全路径
     *
     * @param path 文件
     * @return 目录全路径
     */
    public static String getDirectory(String path) {
        File file = new File(path);
        if (file.exists()) {
            if (file.isDirectory()) {
                return path;
            }
            return file.getParent();
        }
        return StringUtil.EMPTY;
    }

    /**
     * 获取文件后缀
     *
     * @param filePath 文件路径
     * @param haveDot  是否带点号"."
     * @return 文件后缀
     */
    public static String getExtension(String filePath, boolean haveDot) {
        File file = new File(filePath);
        if (!file.exists()) {
            LOG.error(constant.PATH.PATH_NOT_EXIST, filePath);
            return StringUtil.EMPTY;
        }
        if (file.isDirectory()) {
            LOG.error(constant.PATH.PATH_NOT_VALID_FILE, filePath);
            return StringUtil.EMPTY;
        }
        String fileName = file.getName();
        if (haveDot) {
            return fileName.substring(fileName.lastIndexOf(constant.STRING.PERIOD));
        }
        return fileName.substring(fileName.lastIndexOf(constant.STRING.PERIOD) + 1);
    }

    /**
     * 获取文件名称，非路径
     *
     * @param filePath 文件路径
     * @return 文件名称
     */
    public static String getFileName(String filePath) {
        File file = new File(filePath);
        if (file.exists()) {
            return file.getName();
        }
        return StringUtil.EMPTY;
    }

    /**
     * 获取不带扩展名的文件名称
     *
     * @param filePath 文件路径（需要存在）
     * @return 文件名称
     */
    public static String getFileNameWithoutExtension(String filePath) {
        File file = new File(filePath);
        if (file.exists()) {
            return file.getName().substring(0, file.getName().lastIndexOf(constant.STRING.PERIOD));
        }
        return StringUtil.EMPTY;
    }
}