package com.citygis.common.boot.util;

import cn.hutool.core.util.StrUtil;

/**
 * 字符串工具类
 */
public final class StringUtil {
    public final static String EMPTY = StringUtil.EMPTY;

    /**
     * 判断是否NULL或空字符串
     *
     * @param str 字符串
     * @return 是否NULL或空字符串
     */
    public static boolean isNullOrEmpty(String str) {
        return StrUtil.isEmptyIfStr(str);
    }

    /**
     * 字符串比较，忽略大小写
     *
     * @param a 字符串A
     * @param b 字符串B
     * @return 是否相同字符串
     */
    public static boolean equalsIgnoreCase(String a, String b) {
        if (isNullOrEmpty(a) || isNullOrEmpty(b)) {
            return false;
        }
        return a.equalsIgnoreCase(b);
    }

    /**
     * 字符串比较
     *
     * @param a 字符串A
     * @param b 字符串B
     * @return 是否相同字符串
     */
    public static boolean equals(String a, String b) {
        if (isNullOrEmpty(a) || isNullOrEmpty(b)) {
            return false;
        }
        return a.equals(b);
    }

    /**
     * 不足位往右填充字符
     *
     * @param str         原文
     * @param totalWidth  总位数
     * @param paddingChar 填充字符
     * @return 填充结果
     */
    public static String padRight(String str, int totalWidth, String paddingChar) {
        int strLen = str.length();
        StringBuilder sb = null;
        while (strLen < totalWidth) {
            sb = new StringBuilder();
            sb.append(str).append(paddingChar);// 右补0
            str = sb.toString();
            strLen = str.length();
        }
        return str;
    }

    /**
     * 不足位往左填充字符
     *
     * @param str         原文
     * @param totalWidth  总位数
     * @param paddingChar 填充字符
     * @return 填充结果
     */
    public static String padLeft(String str, int totalWidth, String paddingChar) {
        int strLen = str.length();
        StringBuilder sb = null;
        while (strLen < totalWidth) {
            sb = new StringBuilder();
            sb.append(paddingChar).append(str);// 左补0
            str = sb.toString();
            strLen = str.length();
        }
        return str;
    }

    /**
     * 格式化字符串。如果value为null，则返回空字符串StringUtil.EMPTY；否则返回value.toString。
     * 不直接使用String.valueOf
     * 
     * @param value 字符串
     * @return 格式化结果
     */
    public static String valueOf(Object value) {
        if (null == value) {
            return StringUtil.EMPTY;
        }
        return value.toString();
    }

    /**
     * 截取字符串
     * 
     * @param startIndex 起始索引号，从0开始
     * @param length     截取长度
     * @return 截取结果
     */
    public static String substring(String str, int startIndex, int length) {
        if (isNullOrEmpty(str)) {
            return StringUtil.EMPTY;
        }
        if (startIndex >= str.length()) {
            return StringUtil.EMPTY;
        }
        if (startIndex + length >= str.length()) {
            return StringUtil.EMPTY;
        }
        return str.substring(startIndex, startIndex + length);
    }

    /**
     * 是否以指定字符串结尾(忽略大小写)
     * 如果给定的字符串和开头字符串都为null则返回true，否则任意一个值为null返回false
     *
     * @param str    被监测字符串
     * @param suffix 结尾字符串
     * @return 是否以指定字符串结尾
     */
    public static boolean endWithIgnoreCase(String str, String suffix) {
        if (isNullOrEmpty(str) || isNullOrEmpty(suffix)) {
            return false;
        }
        return StrUtil.endWith(str, suffix, true);
    }
}
